Skip to contents

Retrieves circuit information, optionally filtered to circuits used in a specific season.

Usage

f1_circuits(season = NULL)

Arguments

season

Integer or character. The season year (e.g., 2024). If NULL (default), returns all circuits in the database.

Value

A tibble with one row per circuit, including columns:

circuit_id

Character. Unique circuit identifier.

circuit_name

Character. Full circuit name.

location_locality

Character. City or locality.

location_country

Character. Country.

location_lat

Numeric. Latitude.

location_long

Numeric. Longitude.

url

Character. Wikipedia URL.

See also

f1_races() for the race schedule including circuit details.

Other reference data: f1_constructors(), f1_drivers(), f1_races(), f1_seasons()

Examples

if (FALSE) { # \dontrun{
# All circuits in the database
f1_circuits()

# Circuits used in a specific season
f1_circuits(2024)
} # }