Skip to contents

Removes all cached API responses from the current R session. API responses are cached in memory for one hour to reduce redundant requests. Use this function to force fresh data from the API on subsequent calls.

Usage

f1_clear_cache()

Value

Invisible NULL. A success message is printed via cli::cli_alert_success().

Examples

f1_clear_cache()
#>  pitlaneR cache cleared.