Skip to contents

Retrieves constructor (team) information, optionally filtered to constructors that participated in a specific season.

Usage

f1_constructors(season = NULL)

Arguments

season

Integer or character. The season year (e.g., 2024). If NULL (default), returns all constructors in the database.

Value

A tibble with one row per constructor, including columns:

constructor_id

Character. Unique constructor identifier.

name

Character. Constructor name.

nationality

Character. Constructor nationality.

url

Character. Wikipedia URL.

See also

f1_drivers() for driver information.

Other reference data: f1_circuits(), f1_drivers(), f1_races(), f1_seasons()

Examples

if (FALSE) { # \dontrun{
# Constructors from a specific season
f1_constructors(2024)

# All constructors in the database
f1_constructors()
} # }