Skip to contents

Retrieves a list of all Formula 1 World Championship seasons available in the database, covering 1950 to the present.

Usage

f1_seasons()

Value

A tibble with one row per season, including columns:

season

Integer. The season year.

url

Character. Wikipedia URL for the season.

See also

Examples

if (FALSE) { # \dontrun{
f1_seasons()
} # }